#
# spec file for package python-recommonmark
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-recommonmark
Version:        0.7.1
Release:        4.6
Summary:        Python docutils-compatibility bridge to CommonMark
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/rtfd/recommonmark
Source:         https://files.pythonhosted.org/packages/source/r/recommonmark/recommonmark-%{version}.tar.gz
#Source0:        https://github.com/rtfd/recommonmark/archive/%%{version}.tar.gz#/recommonmark-%%{version}.tar.gz
Patch0:         sphinx2.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-CommonMark >= 0.7.3
Requires:       python-Sphinx >= 1.3.1
Requires:       python-docutils >= 0.11
Requires(post): update-alternatives
Requires(postun):update-alternatives
Requires(preun):update-alternatives
Provides:       python-reCommonMark = %{version}
Obsoletes:      python-reCommonMark < %{version}
BuildArch:      noarch
# SECTION tests
BuildRequires:  %{python_module CommonMark >= 0.7.3}
BuildRequires:  %{python_module Sphinx >= 1.3.1}
BuildRequires:  %{python_module docutils >= 0.11}
BuildRequires:  %{python_module pytest}
# /SECTION tests
%python_subpackages

%description
A python docutils-compatibility bridge to CommonMark.

This allows you to write CommonMark inside of Docutils & Sphinx projects.

Documentation is available on Read the Docs:
http://recommonmark.readthedocs.org

%prep
%autosetup -p1 -n recommonmark-%{version}
# Remove upstream's egg-info
rm -rf %{pypi_name}.egg-info
# find and remove unneeded shebangs
find recommonmark -name "*.py" | xargs sed -i '1 {/^#!/ d}'

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%python_clone -a %{buildroot}%{_bindir}/cm2html
%python_clone -a %{buildroot}%{_bindir}/cm2latex
%python_clone -a %{buildroot}%{_bindir}/cm2man
%python_clone -a %{buildroot}%{_bindir}/cm2pseudoxml
%python_clone -a %{buildroot}%{_bindir}/cm2xetex
%python_clone -a %{buildroot}%{_bindir}/cm2xml

%check
# gh#readthedocs/recommonmark#200
%pytest -k 'not (test_integration or test_code or test_headings or test_image or test_links or test_lists)'

%post
%{python_install_alternative cm2man cm2latex cm2xetex cm2pseudoxml cm2html cm2xml}

%postun
%{python_uninstall_alternative cm2man cm2latex cm2xetex cm2pseudoxml cm2html cm2xml}

%preun
%python_uninstall_alternative cm2man

%files %{python_files}
%license license.md
%python_alternative %{_bindir}/cm2html
%python_alternative %{_bindir}/cm2latex
%python_alternative %{_bindir}/cm2man
%python_alternative %{_bindir}/cm2pseudoxml
%python_alternative %{_bindir}/cm2xetex
%python_alternative %{_bindir}/cm2xml
%{python_sitelib}/recommonmark/
%{python_sitelib}/recommonmark-%{version}.dist-info
%doc README.md CHANGELOG.md

%changelog
* Fri Sep  1 2023 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject and autosetup macros.
- Add missing postun section.
- Drop unneeded future requirement.
* Thu May 11 2023 Johannes Kastl <kastl@b1-systems.de>
- add sle15_python_module_pythons
* Wed Nov 17 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- Disable Python 2 because Package is not able to build with Python 2 on Leap 15.3 because of "nothing provides python2-charset-normalizer >= 2.0.0 needed by python2-requests"
* Sun Dec 20 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 0.7.1:
  - no changelog available
- update to version 0.7.0:
  - Bugfix: External links to 'supported' files lose their file extension ([\#181](https://github.com/readthedocs/recommonmark/pull/181))
* Tue May 12 2020 Matej Cepl <mcepl@suse.com>
- Switch to pytest and ignore failing tests
  (gh#readthedocs/recommonmark#200)
* Fri Aug  9 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 0.6.0:
  - [@RaptorCZ](http://github.com/RaptorCZ): Process linebreaks and
    convert them to br element.
    ([\#162](https://github.com/readthedocs/recommonmark/pull/162))
  - [@gibfahn](http://github.com/gibfahn): Remove URL quoting from refs
    before passing to Sphinx
    ([\#158](https://github.com/readthedocs/recommonmark/pull/158))
  - [@dandersson](http://github.com/dandersson): Use image description
    text as \"alt\", drop title
    ([\#150](https://github.com/readthedocs/recommonmark/pull/150))
  - [@annegentle](http://github.com/annegentle): Clarify the specifics
    of Auto Toc Tree
    ([\#149](https://github.com/readthedocs/recommonmark/pull/149))
  - [@loganrosen](http://github.com/loganrosen): Bump dependency on
    commonmark to \>= 0.8.1
    ([\#147](https://github.com/readthedocs/recommonmark/pull/147))
  - [@codejamninja](http://github.com/codejamninja): Use official
    gitignore template
    ([\#140](https://github.com/readthedocs/recommonmark/pull/140))
  - [@dotlambda](http://github.com/dotlambda): Include all test files in
    PyPI tarball
    ([\#128](https://github.com/readthedocs/recommonmark/pull/128))
  - [@tk0miya](http://github.com/tk0miya): Register a parser class using
    new Sphinx API; add\_source\_suffix
    ([\#113](https://github.com/readthedocs/recommonmark/pull/113))
* Thu Jun 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to fix sphinx2 testing (the strings are now wrapped in
  <p> element and the tests didn't account for it:
  * sphinx2.patch
* Sat Mar 16 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- Use github tarball including the tests.
- Enable the tests
- Fix compatibility with recent commonmark.
* Tue Jan 15 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 0.5.0:
  * No upstream changelog available.
- remove unneeded fix-commonmark-compatibility.patch
* Fri Dec  7 2018 Tomáš Chvátal <tchvatal@suse.com>
- Fix the fdupes call
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu Jul 20 2017 sebix+novell.com@sebix.at
- add fix-commonmark-compatibility.patch to fix imported names
* Sat May  6 2017 toddrme2178@gmail.com
- Fix Provides/Obsoletes.
* Thu Apr  6 2017 toddrme2178@gmail.com
- Remove README since the upstream link changes unpredictably and
  there is no consistent way to pick a particular version.
* Mon Apr  3 2017 toddrme2178@gmail.com
- Initial python singlepsec version.
* Thu May 19 2016 toddrme2178@gmail.com
- Update to version 0.4.0
  * No upstream changelog
* Sun May  8 2016 arun@gmx.de
- specfile:
  * updated source url to files.pythonhosted.org
* Thu Dec 10 2015 bruno@ioda-net.ch
- Initial packaging on obs
